Cython: defaults.pyx

Generated by Cython 0.28.4

Yellow lines hint at Python interaction.
Click on a line that starts with a "`+`" to see the C code that Cython generated for it.

Raw output: defaults.c

     1: # cython: language_level=3

     2:

    +3: cdef int DEFAULT_CHANNELS = 2

      __pyx_v_5pippi_8defaults_DEFAULT_CHANNELS = 2;

    +4: cdef int DEFAULT_SAMPLERATE = 44100

      __pyx_v_5pippi_8defaults_DEFAULT_SAMPLERATE = 0xAC44;

    +5: cdef unicode DEFAULT_SOUNDFILE = u'wav'

      __Pyx_INCREF(__pyx_n_u_wav);
      __Pyx_XGOTREF(__pyx_v_5pippi_8defaults_DEFAULT_SOUNDFILE);
      __Pyx_DECREF_SET(__pyx_v_5pippi_8defaults_DEFAULT_SOUNDFILE, __pyx_n_u_wav);
      __Pyx_GIVEREF(__pyx_n_u_wav);